@@ -77,13 +77,15 @@ static char *dicefiles[NUMBER_OF_PIXMAPS] = { PP "gnome-dice-1.xpm",
 
 static GtkWidget *dicePixmaps[NUMBER_OF_DICE][NUMBER_OF_PIXMAPS];
 
-static GtkWidget *window, *appbar, *diceBox[NUMBER_OF_DICE];
+GtkWidget *window;
+static GtkWidget *appbar, *diceBox[NUMBER_OF_DICE];
 static GtkWidget *diceTable;
 
 static gint gnome_modify_dice( GtkWidget *widget, GdkEventButton *event,
                                gpointer data );
 static gint gnome_roll_dice( GtkWidget *widget, GdkEvent *event,
                              gpointer data );
+void update_score_state ();
 
 
 void
@@ -103,6 +105,7 @@ CheerWinner(void)
         if ( (winner<NumberOfHumans) && !IsCheater ) {
                 lastHighScore = gnome_score_log((guint)WinningScore, 
                                                 NULL, TRUE);
+		update_score_state ();
                 if (lastHighScore)
                         ShowHighScores();
         }
@@ -376,6 +379,7 @@ about(GtkWidget *widget, gpointer data)
 				 (const char **)documenters,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				 pixbuf);
+        gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (window));
         gtk_widget_show (about);
 	return FALSE;
 }
@@ -476,6 +480,23 @@ LoadDicePixmaps(void)
 	}
 }
 
+void update_score_state ()
+{
+        gchar **names = NULL;
+        gfloat *scores = NULL;
+        time_t *scoretimes = NULL;
+	gint top;
+
+	top = gnome_score_get_notable(appID, NULL, &names, &scores, &scoretimes);
+	if (top > 0) {
+		gtk_widget_set_sensitive (gamemenu[4].widget, TRUE);
+		g_strfreev(names);
+		g_free(scores);
+		g_free(scoretimes);
+	} else {
+		gtk_widget_set_sensitive (gamemenu[4].widget, FALSE);
+	}
+}
 
 static void
 GyahtzeeCreateMainWindow(void)
@@ -554,6 +575,8 @@ GyahtzeeCreateMainWindow(void)
 
         gtk_widget_show(window);
 
+	update_score_state ();
+
 }
 
 
